summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--AUTHORS4
-rw-r--r--README13
-rw-r--r--README.BRANDING16
-rw-r--r--local_settings.py.example24
-rw-r--r--main/context_processors.py6
-rw-r--r--main/fixtures/arches.json16
-rw-r--r--main/fixtures/groups.json2
-rw-r--r--main/fixtures/repos.json20
-rw-r--r--main/templatetags/wiki.py4
-rw-r--r--packages/templatetags/package_extras.py58
-rw-r--r--packages/utils.py6
-rw-r--r--packages/views/__init__.py5
-rw-r--r--public/views.py43
-rw-r--r--releng/views.py2
-rw-r--r--settings.py30
-rw-r--r--sitestatic/.gitignore3
-rw-r--r--sitestatic/Makefile9
-rw-r--r--sitestatic/archnavbar/archnavbar.css6
-rw-r--r--sitestatic/archnavbar/parabolabw.pngbin0 -> 6595 bytes
-rw-r--r--sitestatic/archweb.css6
-rw-r--r--sitestatic/favicon.icobin575 -> 1150 bytes
-rw-r--r--sitestatic/freedomincluded.pngbin0 -> 3116 bytes
-rw-r--r--sitestatic/gnuchile.pngbin0 -> 7476 bytes
-rw-r--r--sitestatic/js.mk18
-rw-r--r--sitestatic/naltu.pngbin0 -> 5270 bytes
-rw-r--r--sitestatic/silhouette.pngbin2194 -> 2411 bytes
-rw-r--r--sitestatic/venenux.pngbin0 -> 8714 bytes
-rw-r--r--templates/base.html23
-rw-r--r--templates/devel/clock.html10
-rw-r--r--templates/devel/index.html2
-rw-r--r--templates/packages/details.html13
-rw-r--r--templates/packages/differences.html29
-rw-r--r--templates/packages/flag.html4
-rw-r--r--templates/packages/flaghelp.html4
-rw-r--r--templates/packages/opensearch.xml2
-rw-r--r--templates/packages/search.html14
-rw-r--r--templates/public/about.html105
-rw-r--r--templates/public/art.html116
-rw-r--r--templates/public/donate.html66
-rw-r--r--templates/public/download.html114
-rw-r--r--templates/public/feeds.html70
-rw-r--r--templates/public/https.html38
-rw-r--r--templates/public/index.html89
-rw-r--r--templates/public/svn.html41
-rw-r--r--urls.py21
-rw-r--r--visualize/static/.gitignore3
-rw-r--r--visualize/static/Makefile41
-rw-r--r--visualize/static/visualize.js20
48 files changed, 544 insertions, 572 deletions
diff --git a/AUTHORS b/AUTHORS
index 1bfaaf00..5ab816b3 100644
--- a/AUTHORS
+++ b/AUTHORS
@@ -8,3 +8,7 @@ eliott <eliott@cactuswax.net>
Thayer Williams <thayer@archlinux.org>
Dusty Phillips <dusty@archlinux.org>
+# PARABOLAWEB AUTHORS
+Konstantinos Karantias <kostis@gtklocker.com>
+Nicolás Reynolds <fauno@kiwwwi.com.ar>
+Luke Shumaker <lukeshu@sbcglobal.net>
diff --git a/README b/README
index beeb7f99..e3b13063 100644
--- a/README
+++ b/README
@@ -1,3 +1,14 @@
+# Parabolaweb README
+It is recommended that you just install the (parabola) package
+`parabolaweb-utils`, it
+
+ - depends on the dependencies of parabolaweb
+ - offers initscripts and systemd service files for parabolaweb
+ - has a `parabolaweb-update` script that does most of the things here.
+
+Following is Archweb's readme, as I figure it might be useful for some people,
+but I have given up on maintaining it for parabolaweb.
+
# Archweb README
To get a pretty version of this document, run
@@ -44,7 +55,7 @@ packages, you will probably want the following:
(archweb-env) $ pip install -r requirements.txt
3. Copy `local_settings.py.example` to `local_settings.py` and modify.
- Make sure to uncomment the appropriate database section (either sqlite or
+ Make sure to uncomment the appropriate db section (either sqlite or
PostgreSQL).
4. Sync the database to create it.
diff --git a/README.BRANDING b/README.BRANDING
index e438ccc1..37180c4b 100644
--- a/README.BRANDING
+++ b/README.BRANDING
@@ -1,7 +1,7 @@
It is now fairly easy to re-brand archweb.
Replacing logos is still a bit of work.
Here is a summary of the text files that need to be changed to
-re-brand it.
+re-brand it, from the text side.
Files used to configure branding/url stuff
------------------------------------------
@@ -13,12 +13,6 @@ Files used to configure branding/url stuff
Files with minor Arch stuff that's just easier to patch
-------------------------------------------------------
-`releng/views.py`
- * link to `https://bugs.archlinux.org/index.php?project=6`
-
-`templates/packages/opensearch.xml`
- * `<Tags>` includes `archlinux`
-
`templates/packages/flaghelp.html`
* link to "arch-general" mailing list
@@ -31,10 +25,6 @@ Files with minor Arch stuff that's just easier to patch
`templates/packages/search.html`
* link to AUR
-`templates/public/feeds.html`
- * links to AUR
- * links to feeds on `bugs.archlinux.org`
-
`urls.py`
`releng/views.py`
`releng/models.py`
@@ -68,6 +58,10 @@ Files with a significant amount of Arch-specific content:
* Arch's donate button
* Arch's sponsors
+`templates/public/feeds.html`
+ * links to AUR
+ * links to feeds on `bugs.archlinux.org`
+
Files with totally Arch-specific content:
-----------------------------------------
diff --git a/local_settings.py.example b/local_settings.py.example
index 4be1e2e9..3e33aa7e 100644
--- a/local_settings.py.example
+++ b/local_settings.py.example
@@ -1,9 +1,9 @@
-### Django settings for archlinux project.
+### Django settings for Parabola GNU/Linux-libre project.
## Debug settings
-DEBUG = False
+DEBUG = False # If you are running without another HTTP server, must be true
TEMPLATE_DEBUG = False
-#DEBUG_TOOLBAR = True
+DEBUG_TOOLBAR = False # Must install package django-debug-toolbar to use
## For django debug toolbar
INTERNAL_IPS = ('127.0.0.1',)
@@ -25,6 +25,20 @@ ADMINS = (
# },
#}
+## MySQL Database settings
+#DATABASES = {
+# 'default': {
+# 'ENGINE' : 'django.db.backends.mysql',
+# 'NAME' : 'archlinux',
+# 'USER' : 'archlinux',
+# 'PASSWORD': 'archlinux',
+# 'HOST' : '',
+# 'PORT' : '',
+# # InnoDB WILL NOT work
+# 'OPTIONS' : {'init_command': 'SET storage_engine=MyISAM'},
+# },
+#}
+
## Sqlite Database settings
DATABASES = {
'default': {
@@ -50,10 +64,10 @@ CACHE_MIDDLEWARE_SECONDS = 300
SESSION_COOKIE_SECURE = False
## location for saving dev pictures (the 'devs' folder should be inside of this)
-MEDIA_ROOT = '/srv/example.com/img/'
+MEDIA_ROOT = '/srv/http/web-uploads'
## web url for serving image files (the 'devs' folder should be inside of this)
-MEDIA_URL = '/media/img/'
+MEDIA_URL = '/img/'
## Make this unique, and don't share it with anybody.
SECRET_KEY = '00000000000000000000000000000000000000000000000'
diff --git a/main/context_processors.py b/main/context_processors.py
index 2543a3de..94e83e72 100644
--- a/main/context_processors.py
+++ b/main/context_processors.py
@@ -4,13 +4,15 @@ def secure(request):
def branding(request):
from django.conf import settings
return {
+ 'MAILMAN_BASE_URL': settings.MAILMAN_BASE_URL,
+ 'BUGTRACKER_URL': settings.BUGTRACKER_URL,
+
'BRANDING_APPNAME': settings.BRANDING_APPNAME,
'BRANDING_DISTRONAME': settings.BRANDING_DISTRONAME,
'BRANDING_SHORTNAME': settings.BRANDING_SHORTNAME,
'BRANDING_WIKINAME': settings.BRANDING_WIKINAME,
'BRANDING_EMAIL': settings.BRANDING_EMAIL,
- 'MAILMAN_BASE_URL': settings.MAILMAN_BASE_URL,
- 'BUGTRACKER_URL': settings.BUGTRACKER_URL,
+ 'BRANDING_OSEARCH_TAGS': settings.BRANDING_OSEARCH_TAGS,
}
# vim: set ts=4 sw=4 et:
diff --git a/main/fixtures/arches.json b/main/fixtures/arches.json
index 6334c2d3..f7e7fdc0 100644
--- a/main/fixtures/arches.json
+++ b/main/fixtures/arches.json
@@ -22,5 +22,21 @@
"agnostic": false,
"name": "x86_64"
}
+ },
+ {
+ "pk": 4,
+ "model": "main.arch",
+ "fields": {
+ "agnostic": false,
+ "name": "mips64el"
+ }
+ },
+ {
+ "pk": 5,
+ "model": "main.arch",
+ "fields": {
+ "agnostic": false,
+ "name": "i586"
+ }
}
]
diff --git a/main/fixtures/groups.json b/main/fixtures/groups.json
index 134b98b3..c309095e 100644
--- a/main/fixtures/groups.json
+++ b/main/fixtures/groups.json
@@ -3,7 +3,7 @@
"pk": 1,
"model": "auth.group",
"fields": {
- "name": "Developers",
+ "name": "Hackers",
"permissions": [
[
"change_package",
diff --git a/main/fixtures/repos.json b/main/fixtures/repos.json
index a6f564b7..655be64a 100644
--- a/main/fixtures/repos.json
+++ b/main/fixtures/repos.json
@@ -142,5 +142,25 @@
"svn_root": "packages",
"testing": true
}
+ },
+ {
+ "pk": 10,
+ "model": "main.repo",
+ "fields": {
+ "svn_root": "",
+ "testing": true,
+ "name": "Libre-Testing",
+ "bugs_project": 0
+ }
+ },
+ {
+ "pk": 11,
+ "model": "main.repo",
+ "fields": {
+ "svn_root": "",
+ "testing": false,
+ "name": "Libre",
+ "bugs_project": 0
+ }
}
]
diff --git a/main/templatetags/wiki.py b/main/templatetags/wiki.py
index b1b8dd55..4a3b2f83 100644
--- a/main/templatetags/wiki.py
+++ b/main/templatetags/wiki.py
@@ -4,6 +4,6 @@ register = template.Library()
@register.simple_tag
def wiki_url(article=""):
if article == "":
- return "https://wiki.archlinux.org/"
+ return "https://wiki.parabolagnulinux.org/"
else:
- return "https://wiki.archlinux.org/index.php/"+article.replace(' ', '_')
+ return "https://wiki.parabolagnulinux.org/"+article.replace(' ', '_')
diff --git a/packages/templatetags/package_extras.py b/packages/templatetags/package_extras.py
index f7392a96..960fbb4d 100644
--- a/packages/templatetags/package_extras.py
+++ b/packages/templatetags/package_extras.py
@@ -95,6 +95,18 @@ def maintainer_link(user):
@register.simple_tag
+def get_download_link(package):
+ parts = {
+ "repo": package.repo.name.lower(),
+ "arch": package.arch.name,
+ "pkgfile": package.filename
+ }
+ if parts["arch"] == "any":
+ parts["arch"] = "i686"
+ linkbase = "https//repo.parabolagnulinux.org/%(repo)s/os/%(arch)s/%(pkgfile)s"
+ return linkbase % parts
+
+@register.simple_tag
def packager_link(user):
if user:
# TODO don't hardcode
@@ -106,43 +118,51 @@ def packager_link(user):
)
return ''
-
-@register.simple_tag
-def scm_link(package, operation):
- parts = (package.repo.svn_root, operation, package.pkgbase)
- linkbase = (
- "https://projects.archlinux.org/svntogit/%s.git/%s/trunk?"
- "h=packages/%s")
- return linkbase % tuple(urlquote(part.encode('utf-8')) for part in parts)
-
-
@register.simple_tag
def get_wiki_link(package):
- url = "https://wiki.archlinux.org/index.php/Special:Search"
+ url = "https://wiki.parabolagnulinux.org/index.php"
data = {
+ 'title': "Special:Search",
'search': package.pkgname,
}
return link_encode(url, data)
@register.simple_tag
+def svn_arch(package):
+ repo = package.repo.name.lower()
+ return svn_link(package, "repos/%s-%s" % (repo, package.arch.name))
+
+@register.simple_tag
+def svn_trunk(package):
+ return svn_link(package, "trunk")
+
+@register.simple_tag
def bugs_list(package):
- url = "https://bugs.archlinux.org/"
+ url = "https://labs.parabola.nu/search/index/issue-tracker"
data = {
- 'project': package.repo.bugs_project,
- 'cat[]': package.repo.bugs_category,
- 'string': package.pkgname,
+ 'titles_only': '1',
+ 'issues': '1',
+ 'q': package.pkgname,
}
return link_encode(url, data)
@register.simple_tag
def bug_report(package):
- url = "https://bugs.archlinux.org/newtask"
+ url = "https://labs.parabola.nu/projects/issue-tracker/issues/new"
+ data = {
+ 'issue[subject]': '[%s] PLEASE ENTER SUMMARY' % package.pkgname,
+ }
+ return link_encode(url, data)
+
+@register.simple_tag
+def flag_unfree(package):
+ url = "https://labs.parabola.nu/projects/issue-tracker/issues/new"
data = {
- 'project': package.repo.bugs_project,
- 'product_category': package.repo.bugs_category,
- 'item_summary': '[%s] PLEASE ENTER SUMMARY' % package.pkgname,
+ 'issue[priority_id]': '1', # "freedom issue"
+ 'issue[watcher_user_ids][]': '62', # "dev-list"
+ 'issue[subject]': '[%s] Please put your reasons here (register first if you haven\'t)' % package.pkgname,
}
return link_encode(url, data)
diff --git a/packages/utils.py b/packages/utils.py
index 4f3b8665..e77dbace 100644
--- a/packages/utils.py
+++ b/packages/utils.py
@@ -137,6 +137,10 @@ SELECT p.id, q.id
)
WHERE p.arch_id IN (%s, %s)
AND (
+ q.arch_id IN (%s, %s)
+ OR q.id IS NULL
+ )
+ AND (
q.id IS NULL
OR p.pkgver != q.pkgver
OR p.pkgrel != q.pkgrel
@@ -144,7 +148,7 @@ SELECT p.id, q.id
)
"""
cursor = connection.cursor()
- cursor.execute(sql, [arch_a.id, arch_b.id])
+ cursor.execute(sql, [arch_a.id, arch_b.id, arch_a.id, arch_b.id])
results = cursor.fetchall()
# column A will always have a value, column B might be NULL
to_fetch = {row[0] for row in results}
diff --git a/packages/views/__init__.py b/packages/views/__init__.py
index c1f0f492..b6e72d62 100644
--- a/packages/views/__init__.py
+++ b/packages/views/__init__.py
@@ -110,14 +110,15 @@ def update(request):
def arch_differences(request):
# TODO: we have some hardcoded magic here with respect to the arches.
- arch_a = Arch.objects.get(name='i686')
- arch_b = Arch.objects.get(name='x86_64')
+ arch_a = Arch.objects.get(name=request.GET.get('arch_a', 'i686'))
+ arch_b = Arch.objects.get(name=request.GET.get('arch_b', 'x86_64'))
differences = get_differences_info(arch_a, arch_b)
multilib_diffs = multilib_differences()
context = {
'arch_a': arch_a,
'arch_b': arch_b,
'differences': differences,
+ 'arches': Arch.objects.filter(agnostic=False),
'multilib_differences': multilib_diffs
}
return render(request, 'packages/differences.html', context)
diff --git a/public/views.py b/public/views.py
index 71098c95..ede8e697 100644
--- a/public/views.py
+++ b/public/views.py
@@ -9,6 +9,8 @@ from django.http import Http404, HttpResponse
from django.shortcuts import render
from django.views.decorators.cache import cache_control, cache_page
+from django.views.generic.simple import direct_to_template
+
from devel.models import MasterKey, PGPSignature
from main.models import Arch, Repo, Donor
from mirrors.models import MirrorUrl
@@ -30,35 +32,28 @@ def index(request):
return render(request, 'public/index.html', context)
USER_LISTS = {
- 'devs': {
- 'user_type': 'Developers',
- 'user_title': 'Developer',
- 'description': "This is a list of the current "+settings.BRANDING_DISTRONAME+" Developers. They maintain the [core] and [extra] package repositories in addition to doing any other developer duties.",
- },
- 'tus': {
- 'user_type': 'Trusted Users',
- 'user_title': 'Trusted User',
- 'description': "Here are all your friendly "+settings.BRANDING_DISTRONAME+" Trusted Users who are in charge of the [community] repository.",
+ 'hackers': {
+ 'user_type': 'Hackers',
+ 'user_title': 'Hacker',
+ 'description': "This is a list of the current "+settings.BRANDING_SHORTNAME+" Hackers. They maintain the [libre] package repository and keep the [core], [extra] and [community] repositories clean of unfree software, in addition to doing any other developer duties.",
},
'fellows': {
'user_type': 'Fellows',
'user_title': 'Fellow',
- 'description': "Below you can find a list of ex-developers (aka project fellows). These folks helped make "+settings.BRANDING_SHORTNAME+" what it is today. Thanks!",
+ 'description': "Below you can find a list of ex-hackers (aka project fellows). These folks helped make "+settings.BRANDING_SHORTNAME+" what it is today. Thanks!",
},
}
@cache_control(max_age=300)
-def userlist(request, user_type='devs'):
+def userlist(request, user_type='hackers'):
users = User.objects.order_by(
- 'first_name', 'last_name').select_related('userprofile')
- if user_type == 'devs':
- users = users.filter(is_active=True, groups__name="Developers")
- elif user_type == 'tus':
- users = users.filter(is_active=True, groups__name="Trusted Users")
+ 'username').select_related('userprofile')
+ if user_type == 'hackers':
+ users = users.filter(is_active=True, groups__name="Hackers")
elif user_type == 'fellows':
users = users.filter(is_active=False,
- groups__name__in=["Developers", "Trusted Users"])
+ groups__name__in=["Hackers"])
else:
raise Http404
@@ -88,19 +83,7 @@ def _mirror_urls():
@cache_control(max_age=300)
def download(request):
- try:
- release = Release.objects.filter(available=True).latest()
- except Release.DoesNotExist:
- release = None
-
- context = {
- 'release': release,
- 'releng_iso_url': settings.ISO_LIST_URL,
- 'releng_pxeboot_url': settings.PXEBOOT_URL,
- 'mirror_urls': _mirror_urls,
- }
- return render(request, 'public/download.html', context)
-
+ return redirect('https://wiki.parabolagnulinux.org/get', permanent=True)
@cache_control(max_age=300)
def feeds(request):
diff --git a/releng/views.py b/releng/views.py
index b1c76a4a..ca0a7dd2 100644
--- a/releng/views.py
+++ b/releng/views.py
@@ -50,7 +50,7 @@ class TestForm(forms.ModelForm):
success = forms.BooleanField(
help_text="Only check this if everything went fine. "
"If you ran into problems please create a ticket on <a "
- "href=\"https://bugs.archlinux.org/index.php?project=6\">the "
+ "href=\""+settings.BUGTRACKER_RELENG_URL+"\">the "
"bugtracker</a> (or check that one already exists) and link to "
"it in the comments.",
required=False)
diff --git a/sitestatic/.gitignore b/sitestatic/.gitignore
new file mode 100644
index 00000000..14bd2d31
--- /dev/null
+++ b/sitestatic/.gitignore
@@ -0,0 +1,3 @@
+jquery-1.4.4.js
+jquery-1.4.4.min.js
+jquery.tablesorter.min.js
diff --git a/sitestatic/Makefile b/sitestatic/Makefile
new file mode 100644
index 00000000..f7499d64
--- /dev/null
+++ b/sitestatic/Makefile
@@ -0,0 +1,9 @@
+jqueryversion=1.4.4
+targets=jquery-$(jqueryversion).js jquery-$(jqueryversion).min.js jquery.tablesorter.min.js
+
+all: $(targets) .gitignore
+
+jquery-$(jqueryversion).js:
+ wget http://code.jquery.com/$@
+
+include js.mk
diff --git a/sitestatic/archnavbar/archnavbar.css b/sitestatic/archnavbar/archnavbar.css
index d10c5f52..20cd2ac9 100644
--- a/sitestatic/archnavbar/archnavbar.css
+++ b/sitestatic/archnavbar/archnavbar.css
@@ -5,15 +5,15 @@
*/
/* container for the entire bar */
-#archnavbar { height: 40px !important; padding: 10px 15px !important; background: #333 !important; border-bottom: 5px #08c solid !important; }
-#archnavbarlogo { background: url('archlogo.png') no-repeat !important; }
+#archnavbar { height: 40px !important; padding: 10px 15px !important; background: #000 !important; border-bottom: 5px #787DAB solid !important; }
+#archnavbarlogo { background: url('parabolabw.png') no-repeat !important; }
/* move the heading/paragraph text offscreen */
#archnavbarlogo p { margin: 0 !important; padding: 0 !important; text-indent: -9999px !important; }
#archnavbarlogo h1 { margin: 0 !important; padding: 0 !important; text-indent: -9999px !important; }
/* make the link the same size as the logo */
-#archnavbarlogo a { display: block !important; height: 40px !important; width: 190px !important; }
+#archnavbarlogo a { display: block !important; height: 50px !important; width: 397px !important; }
/* display the list inline, float it to the right and style it */
#archnavbar ul { display: inline !important; float: right !important; list-style: none !important; margin: 0 !important; padding: 0 !important; }
diff --git a/sitestatic/archnavbar/parabolabw.png b/sitestatic/archnavbar/parabolabw.png
new file mode 100644
index 00000000..0e16d33f
--- /dev/null
+++ b/sitestatic/archnavbar/parabolabw.png
Binary files differ
diff --git a/sitestatic/archweb.css b/sitestatic/archweb.css
index b7d6e1ee..a892efbf 100644
--- a/sitestatic/archweb.css
+++ b/sitestatic/archweb.css
@@ -478,7 +478,7 @@ table thead th.sorter-false {
/* home: arrowed headings */
#news h3 a {
display: block;
- background: #1794D1;
+ background: #787DAB;
font-size: 15px;
padding: 2px 10px;
color: white;
@@ -494,7 +494,7 @@ h3 span.arrow {
height: 0;
border-left: 6px solid transparent;
border-right: 6px solid transparent;
- border-top: 6px solid #1794D1;
+ border-top: 6px solid #787DAB;
margin: 0 auto;
font-size: 0;
line-height: 0px;
@@ -503,7 +503,7 @@ h3 span.arrow {
/* home: pkgsearch box */
#pkgsearch {
padding: 1em 0.75em;
- background: #3ad;
+ background: #787DAB;
color: #fff;
border: 1px solid #08b;
}
diff --git a/sitestatic/favicon.ico b/sitestatic/favicon.ico
index 55497b85..3e43f9bd 100644
--- a/sitestatic/favicon.ico
+++ b/sitestatic/favicon.ico
Binary files differ
diff --git a/sitestatic/freedomincluded.png b/sitestatic/freedomincluded.png
new file mode 100644
index 00000000..87ce39be
--- /dev/null
+++ b/sitestatic/freedomincluded.png
Binary files differ
diff --git a/sitestatic/gnuchile.png b/sitestatic/gnuchile.png
new file mode 100644
index 00000000..b6f9bfb8
--- /dev/null
+++ b/sitestatic/gnuchile.png
Binary files differ
diff --git a/sitestatic/js.mk b/sitestatic/js.mk
new file mode 100644
index 00000000..4c803be6
--- /dev/null
+++ b/sitestatic/js.mk
@@ -0,0 +1,18 @@
+closurecompiler=@compiler() { cp "$$1" "$${1%.js}.min.js"; echo "compiler $$*"; }; compiler
+
+%.min.js: %.js
+ $(closurecompiler) '$<'
+
+.gitignore: FORCE
+ for file in $(gitignore) $(targets); do echo $$file; done | sort > $@
+
+clean: PHONY
+distclean-hook: clean
+distclean: clean distclean-hook
+ rm -f $(targets)
+
+FORCE: PHONY
+PHONY:
+.PHONY: PHONY
+
+.SECONDARY:
diff --git a/sitestatic/naltu.png b/sitestatic/naltu.png
new file mode 100644
index 00000000..0fb4624b
--- /dev/null
+++ b/sitestatic/naltu.png
Binary files differ
diff --git a/sitestatic/silhouette.png b/sitestatic/silhouette.png
index 37e6cf33..c957292e 100644
--- a/sitestatic/silhouette.png
+++ b/sitestatic/silhouette.png
Binary files differ
diff --git a/sitestatic/venenux.png b/sitestatic/venenux.png
new file mode 100644
index 00000000..9db96bba
--- /dev/null
+++ b/sitestatic/venenux.png
Binary files differ
diff --git a/templates/base.html b/templates/base.html
index 5702c8e0..24bae3e0 100644
--- a/templates/base.html
+++ b/templates/base.html
@@ -20,10 +20,9 @@
<ul id="archnavbarlist">
<li id="anb-home"><a href="/" title="{{ BRANDING_SHORTNAME }} news, packages, projects and more">Home</a></li>
<li id="anb-packages"><a href="/packages/" title="{{ BRANDING_SHORTNAME }} Package Database">Packages</a></li>
- <li id="anb-forums"><a href="https://bbs.archlinux.org/" title="Community forums">Forums</a></li>
<li id="anb-wiki"><a href="{% wiki_url %}" title="Community documentation">Wiki</a></li>
<li id="anb-bugs"><a href="{{ BUGTRACKER_URL }}" title="Report and track bugs">Bugs</a></li>
- <li id="anb-aur"><a href="https://aur.archlinux.org/" title="Arch Linux User Repository">AUR</a></li>
+ <li id="anb-projects"><a href="https://projects.parabolagnulinux.org" title="Our Code">Projects</a></li>
<li id="anb-download"><a href="{% url 'page-download' as pdl %}{{ pdl }}" title="Get {{ BRANDING_DISTRONAME }}">Download</a></li>
</ul>
</div>
@@ -39,10 +38,8 @@
<li><a href="/packages/signoffs/" title="Package signoffs">Signoffs</a></li>
<li><a href="/todo/" title="Developer todo lists">Todos</a></li>
<li><a href="{% url 'devel-clocks' %}" title="Developer world clocks">Dev Clocks</a></li>
- <li><a href="{{ MAILMAN_BASE_URL }}/mailman/private/arch-dev/"
- title="arch-dev mailing list archives">Archives</a></li>
- <li><a href="https://stats.archlinux.org/munin/"
- title="Arch server monitoring">Server Monitoring</a></li>
+ <li><a href="{{ MAILMAN_BASE_URL }}/mailman/listinfo/dev/"
+ title="dev mailing list archives">Archives</a></li>
{% if user.is_staff %}
<li><a href="{% url 'admin:index' %}" title="Django Admin Interface">Django Admin</a></li>
{% endif %}
@@ -69,16 +66,14 @@
</div>
{% endblock %}
<div id="footer">
- <p>Copyright &copy; 2002-{% now "Y" %} <a href="mailto:jvinet@zeroflux.org"
+ <p>Copyleft 2009-{% now "Y" %} Parabola Project. All content is
+ released under the <a
+ href="http://creativecommons.org/licenses/by-sa/3.0/"
+ rel="license">cc by-sa 3.0 unported</a> license.</p>
+ <p>Website software and layout is derivative of archweb,
+ Copyright &copy; 2002-{% now "Y" %} <a href="mailto:jvinet@zeroflux.org"
title="Contact Judd Vinet">Judd Vinet</a> and <a href="mailto:aaron@archlinux.org"
title="Contact Aaron Griffin">Aaron Griffin</a>.</p>
-
- <p>The Arch Linux name and logo are recognized
- <a href="{% wiki_url 'DeveloperWiki:TrademarkPolicy' %}"
- title="Arch Linux Trademark Policy">trademarks</a>. Some rights reserved.</p>
-
- <p>The registered trademark Linux® is used pursuant to a sublicense from LMI,
- the exclusive licensee of Linus Torvalds, owner of the mark on a world-wide basis.</p>
</div>
</div>
{% block script_block %}{% endblock %}
diff --git a/templates/devel/clock.html b/templates/devel/clock.html
index 8970fad0..5b2e358b 100644
--- a/templates/devel/clock.html
+++ b/templates/devel/clock.html
@@ -3,16 +3,16 @@
{% load flags %}
{% load tz %}
-{% block title %}{{ BRANDING_DISTRONAME }} - Developer World Clocks{% endblock %}
+{% block title %}{{ BRANDING_DISTRONAME }} - Hacker World Clocks{% endblock %}
{% block head %}<link rel="stylesheet" type="text/css" href="{% static "flags/fam.css" %}" media="screen, projection" />{% endblock %}
{% block content %}
<div id="dev-clocks-box" class="box">
- <h2>Developer World Clocks</h2>
+ <h2>Hacker World Clocks</h2>
- <p>This page helps prevent you from waking a sleeping developer. It also
- depends on developers keeping the time zone information up to date, so if
+ <p>This page helps prevent you from waking a sleeping hacker. It also
+ depends on hackers keeping the time zone information up to date, so if
you see 'UTC' listed, pester them to update their settings.</p>
<p>The "Last Action" column shows the last time this developer has done
something we know about. Considered dates for each developer include:</p>
@@ -32,7 +32,7 @@
<table id="clocks-table" class="results">
<thead>
<tr>
- <th>Developer</th>
+ <th>Hacker</th>
<th>Username</th>
<th>Alias</th>
<th>Last Action</th>
diff --git a/templates/devel/index.html b/templates/devel/index.html
index f3f32863..036f81fe 100644
--- a/templates/devel/index.html
+++ b/templates/devel/index.html
@@ -4,7 +4,7 @@
{% load package_extras %}
{% load todolists %}
-{% block title %}{{ BRANDING_DISTRONAME }} - Developer Dashboard{% endblock %}
+{% block title %}{{ BRANDING_DISTRONAME }} - Hacker Dashboard{% endblock %}
{% block content %}
<div id="dev-dashboard" class="box">
diff --git a/templates/packages/details.html b/templates/packages/details.html
index 07406fa2..0442db7e 100644
--- a/templates/packages/details.html
+++ b/templates/packages/details.html
@@ -16,14 +16,9 @@
<div id="actionlist">
<h4>Package Actions</h4>
<ul class="small">
- <li>
- <a href="{% scm_link pkg 'tree' %}" title="View source files for {{ pkg.pkgname }}">Source Files</a> /
- <a href="{% scm_link pkg 'log' %}" title="View changes for {{ pkg.pkgname }}">View Changes</a>
- </li>
- <li>
- <a href="{% bugs_list pkg %}" title="View existing bug tickets for {{ pkg.pkgname }}">Bug Reports</a> /
- <a href="{% bug_report pkg %}" title="Report new bug for {{ pkg.pkgname }}">Add New Bug</a>
- </li>
+ <li><a href="{% bugs_list pkg %}" title="View existing bug tickets for {{ pkg.pkgname }}">Bug Reports</a></li>
+ <li><a href="{% bug_report pkg %}" title="Report bug for {{ pkg.pkgname }}">Report a Bug</a></li>
+ <li><a href="{% flag_unfree pkg %}" title="Report {{ pkg.pkgname }} as unfree">Report as unfree</a></li>
<li><a href="{% get_wiki_link pkg %}" title="Search wiki for {{ pkg.pkgname }}">Search Wiki</a></li>
{% if pkg.flag_date %}
<li><span class="flagged">Flagged out-of-date on {{ pkg.flag_date|date }}</span></li>
@@ -44,7 +39,7 @@
onclick="return !window.open('/packages/flaghelp/','FlagHelp',
'height=350,width=450,location=no,scrollbars=yes,menubars=no,toolbars=no,resizable=no');">(?)</a></li>
{% endif %}
- <li><a href="download/" rel="nofollow" title="Download {{ pkg.pkgname }} from mirror">Download From Mirror</a></li>
+ <li><a href="{% get_download_link pkg %}" rel="nofollow" title="Download {{ pkg.pkgname }} from mirror">Download From Mirror</a></li>
</ul>
{% if perms.main.change_package %}
diff --git a/templates/packages/differences.html b/templates/packages/differences.html
index 1a1bf260..d5d782fb 100644
--- a/templates/packages/differences.html
+++ b/templates/packages/differences.html
@@ -8,6 +8,35 @@
<div class="box">
<h2>Package Differences by Architecture</h2>
<div class="filter-criteria">
+ <h3>Select architectures</h3>
+ <form id="arch_selector" method="get" action=".">
+ <fieldset>
+ <legend>Select arches</legend>
+ <div><label for="arch_a" title="Architecture A">Architecture A</label>
+ <select name="arch_a" id="arch_a">
+ {% for arch in arches %}
+ <option
+ {% if arch == arch_a %}
+ selected="selected"
+ {% endif %}
+ >{{ arch }}</option>
+ {% endfor %}
+ </select>
+ </div>
+ <div><label for="arch_b" title="Architecture B">Architecture B</label>
+ <select name="arch_b" id="arch_b">
+ {% for arch in arches %}
+ <option
+ {% if arch == arch_b %}
+ selected="selected"
+ {% endif %}
+ >{{ arch }}</option>
+ {% endfor %}
+ </select>
+ </div>
+ <div><label>&nbsp;</label><input type="submit" title="Show difference between selected architectures"></div>
+ </fieldset>
+ </form>
<h3>Filter Differences View</h3>
<form id="diff_filter" method="post" action=".">
<fieldset>
diff --git a/templates/packages/flag.html b/templates/packages/flag.html
index 063e1d1e..b9737bb9 100644
--- a/templates/packages/flag.html
+++ b/templates/packages/flag.html
@@ -23,8 +23,8 @@
<p>The message box portion of the flag utility is optional, and meant
for short messages only. If you need more than 200 characters for your
message, then file a bug report, email the maintainer directly, or send
- an email to the <a href="{{ MAILMAN_BASE_URL }}/mailman/listinfo/arch-general"
- title="Visit the arch-general mailing list">arch-general mailing list</a>
+ an email to the <a href="{{ MAILMAN_BASE_URL }}/mailman/listinfo/dev"
+ title="Visit the dev mailing list">dev mailing list</a>
with your additional text.</p>
<p><strong>Note:</strong> Do <em>not</em> use this facility if the
diff --git a/templates/packages/flaghelp.html b/templates/packages/flaghelp.html
index 51ace2fd..146e6ade 100644
--- a/templates/packages/flaghelp.html
+++ b/templates/packages/flaghelp.html
@@ -24,8 +24,8 @@
<p>The message box portion of the flag utility is optional, and meant
for short messages only. If you need more than 200 characters for your
message, then file a bug report, email the maintainer directly, or send
- an email to the <a target="_blank" href="{{ MAILMAN_BASE_URL }}/mailman/listinfo/arch-general"
- title="Visit the arch-general mailing list">arch-general mailing list</a>
+ an email to the <a target="_blank" href="{{ MAILMAN_BASE_URL }}/mailman/listinfo/dev"
+ title="Visit the dev mailing list">dev mailing list</a>
with your additional text.</p>
<p><strong>Note:</strong> Please do <em>not</em> use this facility if the
diff --git a/templates/packages/opensearch.xml b/templates/packages/opensearch.xml
index 5aa4d5d7..0004b996 100644
--- a/templates/packages/opensearch.xml
+++ b/templates/packages/opensearch.xml
@@ -3,7 +3,7 @@
<ShortName>{{BRANDING_SHORTNAME}} Packages</ShortName>
<LongName>{{BRANDING_DISTRONAME}} Package Repository Search</LongName>
<Description>Search the {{BRANDING_DISTRONAME}} package repositories by keyword in package names and descriptions.</Description>
- <Tags>linux archlinux package software</Tags>
+ <Tags>{{BRANDING_OSEARCH_TAGS}}</Tags>
<Image height="16" width="16" type="image/x-icon">{{ domain }}{% static "favicon.ico" %}</Image>
<Image height="64" width="64" type="image/png">{{ domain }}{% static "logos/icon-transparent-64x64.png" %}</Image>
<Language>en-us</Language>
diff --git a/templates/packages/search.html b/templates/packages/search.html
index e1be4256..21943a8e 100644
--- a/templates/packages/search.html
+++ b/templates/packages/search.html
@@ -75,7 +75,8 @@
{% endif %}
<td>{{ pkg.arch.name }}</td>
<td>{{ pkg.repo.name|capfirst }}</td>
- <td>{% pkg_details_link pkg %}</td>
+ <td><a href="{{ pkg.get_absolute_url }}"
+ title="Package details for {{ pkg.pkgname }}">{{ pkg.pkgname }}</a></td>
{% if pkg.flag_date %}
<td><span class="flagged">{{ pkg.full_version }}</span></td>
{% else %}
@@ -102,18 +103,15 @@
{% else %}
<div class="box">
<p>We couldn't find any packages matching your query. Try searching again
- using different criteria, or try
- {% if search_form.q.data %}
- <a href="https://aur.archlinux.org/packages.php?K={{ search_form.q.data|urlencode }}">searching the AUR</a>
- {% else %}searching the <a href="https://aur.archlinux.org/">AUR</a>{% endif %}
- to see if the package can be found there.</p>
+ using different criteria.</p>
</div>
{% endif %}
<div id="pkglist-about" class="box">
<p>You are browsing the {{ BRANDING_DISTRONAME }} package database. From here you can find
detailed information about packages located in the official supported repositories.
- For unsupported packages, browse the <a href="https://aur.archlinux.org/"
- title="AUR package database">Arch User Repository (AUR).</a></p>
+ If you need the sourceball from where a package is built, you can look at our <a
+ href="https://repo.parabolagnulinux.org/sources/packages"
+ title="Sourceballed packages">sources repo</a>.</p>
</div>
{% endblock %}
diff --git a/templates/public/about.html b/templates/public/about.html
index f5751d42..b31b05ed 100644
--- a/templates/public/about.html
+++ b/templates/public/about.html
@@ -1,57 +1,62 @@
{% extends "base.html" %}
+{% load wiki %}
{% block title %}{{ BRANDING_DISTRONAME }} - About{% endblock %}
{% block content %}
<div class="box">
- <h2 class="title">About Arch Linux</h2>
-<p>
-Arch Linux is an independently developed, i686/x86-64 general purpose GNU/Linux
-distribution versatile enough to suit any role. Development focuses on
-simplicity, minimalism, and code elegance. Arch is installed as a
-minimal base system, configured by the user upon which their own ideal
-environment is assembled by installing only what is required or desired
-for their unique purposes. GUI configuration utilities are not officially
-provided, and most system configuration is performed from the shell by editing
-simple text files. Arch strives to stay bleeding edge, and typically offers
-the latest stable versions of most software.
-</p>
-<p>
-Arch Linux uses its own Pacman package manager, which couples simple binary
-packages with an easy-to-use package build system. This allows users to
-easily manage and customize packages ranging from official Arch software to the
-user's own personal packages to packages from 3rd party sources. The repository
-system also allows users to easily build and maintain their own custom build
-scripts, packages, and repositories, encouraging community growth and
-contribution.
-</p>
-<p>
-The minimal Arch base package set resides in the streamlined [core] repository.
-In addition, the official [extra], [community], and [testing] repositories
-provide several thousand high-quality, packages to meet your software demands.
-Arch also offers an [unsupported] section in the Arch Linux User Repository
-(AUR), which contains over 9,000 build scripts, for compiling installable
-packages from source using the Arch Linux makepkg application.
-</p>
-<p>
-Arch Linux uses a "rolling release" system which allows one-time installation
-and perpetual software upgrades. It is not generally necessary to reinstall
-or upgrade your Arch Linux system from one "version" to the next.
-By issuing one command, an Arch system is kept up-to-date and on the bleeding
-edge.
-</p>
-<p>
-Arch strives to keep its packages as close to the original upstream software as
-possible. Patches are applied only when necessary to ensure an application
-compiles and runs correctly with the other packages installed on an up-to-date
-Arch system.
-</p>
-<p>
-To summarize: Arch Linux is a versatile, and simple distribution designed to
-fit the needs of the competent Linux&#0174; user. It is both powerful and easy
-to manage, making it an ideal distro for servers and workstations. Take it in
-any direction you like. If you share this vision of what a GNU/Linux
-distribution should be, then you are welcomed and encouraged to use it freely,
-get involved, and contribute to the community. Welcome to Arch!
-</p>
+ <h2 class="title">Parabola Presentation</h2>
+
+ <p>In 2009 we started a project to offer the Free Software
+ community the chance of using an Arch Linux system completely
+ freed from proprietary software.</p>
+
+ <p>Today we have repositories and installable images of this wonderful
+ GNU/Linux distribution from which we have eliminated the non-free software
+ contained in its official repositories and which we have replaced with libre
+ alternatives whenever we could.</p>
+
+ <p>The first example is Linux-libre, the kernel without blobs nor nonfree
+ firmware. Followed by GNU IceCat, the libre fork of Mozilla Firefox that
+ doesn't recommend non-libre addons, and that in our case neither recommends
+ services that spy on you like the Google search engine.</p>
+
+ <h3>Why you should use Parabola</h3>
+
+ <p>Parabola equals software freedom plus all power to the users. GNU plus
+ ArchWay. With a continuosly updated system, simple to manage, simple to
+ package, you can build your own operating system in the way you want and
+ learn a lot along the way.</p>
+
+ <h3>Free Arch Linux</h3>
+
+ <p>Following the minimalist, KISS, spirit of Arch, we have managed to
+ achieve its freedom in a simple way. To free your Arch Linux installation,
+ just install our libre repositories list and update your system.</p>
+
+ <p>No reinstallation needed.</p>
+
+ <h3>Participate</h3>
+
+ <p>Boring tasks are always available. We want to start new projects. We want
+ to help people have servers of their own, with services of their own, with
+ Parabola Social. We want people to remix their own Arch Linux and share it
+ with the rest of the world.</p>
+
+ <p>We want Free Software with a social utility for a libre society.</p>
+
+ <p>But we need your help. If all of us share a little of the boring work,
+ we'll have more time to do the really fun stuff.</p>
+
+ <p>Remaining tasks:</p>
+
+ <ul>
+ <li>Audit repositories. If you find a non-libre package, or a package
+ with non-libre parts, report it as a bug.</li>
+
+ <li>Host repositories. Mirrors are not abundant.</li>
+
+ <li>Take a look at our <a href="{% wiki_url 'TODO' %}" title="TODO">TODO list</a></li>
+ </ul>
+
</div>
<br /><br />
{% endblock %}
diff --git a/templates/public/art.html b/templates/public/art.html
index 89f1f81e..8aad43f4 100644
--- a/templates/public/art.html
+++ b/templates/public/art.html
@@ -7,125 +7,51 @@
<div id="artwork" class="box">
<h2>{{ BRANDING_DISTRONAME }} Logos and Artwork</h2>
+
+ <p>You can help by creating artwork for {{ BRANDING_DISTRONAME }}.</p>
+ <p>Send your designs to dev@lists.parabolagnulinux.org and state they are CC-by-sa
+ or another free culture friendly license.</p>
+
+{% comment %}
<h3>Logos for Press Usage</h3>
- <p>The following {{BRANDING_DISTRONAME}} logos are available for press and other use, subject to
- the restrictions of our <a href="{% wiki_url 'DeveloperWiki:TrademarkPolicy' %}"
- title="{{BRANDING_DISTRONAME}} Trademark Policy">trademark policy</a>.</p>
+ <p>The following {{BRANDING_DISTRONAME}} logos are available for press and other use.</p>
<p><strong>Two-color standard version</strong><br />
+
+<!-- This is an example of how images should be added here -->
<em>Also available in print-quality
- <a href="{% static "logos/archlinux-logo-dark-1200dpi.png" %}"
+ <a href="{% static "logos/parabola-logo-dark-1200dpi.png" %}"
title="Download 1200dpi PNG format">PNG</a> and scalable
- <a href="{% static "logos/archlinux-logo-dark-scalable.svg" %}"
+ <a href="{% static "logos/parabola-logo-dark-scalable.svg" %}"
title="Download scalable SVG format">SVG</a> formats.</em></p>
- <img src="{% static "logos/archlinux-logo-dark-90dpi.png" %}"
- alt="Arch Linux PNG logo @ 90dpi" title="Arch Linux PNG logo @ 90dpi" />
+ <img src="{% static "logos/parabola-logo-dark-90dpi.png" %}"
+ alt="Parabola PNG logo @ 90dpi" title="Parabola PNG logo @ 90dpi" />
<p><strong>Two-color inverted version</strong> (for dark backgrounds)<br />
- <em>Also available in print-quality
- <a href="{% static "logos/archlinux-logo-light-1200dpi.png" %}"
- title="Download 1200dpi PNG format">PNG</a> and scalable
- <a href="{% static "logos/archlinux-logo-light-scalable.svg" %}"
- title="Download scalable SVG format">SVG</a> formats.</em></p>
- <img src="{% static "logos/archlinux-logo-light-90dpi.png" %}"
- alt="Arch Linux PNG logo @ 90dpi" title="Arch Linux PNG logo @ 90dpi" class="inverted" />
<p><strong>One-color standard version</strong><br />
- <em>Also available in print-quality
- <a href="{% static "logos/archlinux-logo-black-1200dpi.png" %}"
- title="Download 1200dpi PNG format">PNG</a> and scalable
- <a href="{% static "logos/archlinux-logo-black-scalable.svg" %}"
- title="Download scalable SVG format">SVG</a> formats.</em></p>
- <img src="{% static "logos/archlinux-logo-black-90dpi.png" %}"
- alt="Arch Linux PNG logo @ 90dpi" title="Arch Linux PNG logo @ 90dpi" />
<p><strong>One-colour inverted version</strong> (for dark backgrounds)<br />
- <em>Also available in print-quality
- <a href="{% static "logos/archlinux-logo-white-1200dpi.png" %}"
- title="Download 1200dpi PNG format">PNG</a> and scalable
- <a href="{% static "logos/archlinux-logo-white-scalable.svg" %}"
- title="Download scalable SVG format">SVG</a> formats.</em></p>
-
- <img src="{% static "logos/archlinux-logo-white-90dpi.png" %}"
- alt="Arch Linux PNG logo @ 90dpi" title="Arch Linux PNG logo @ 90dpi" class="inverted" />
<h3>Logos and Artwork for the Community</h3>
- <p>Official logos and artwork are also available directly from the
- repositories. Currently, these packages are:</p>
+ <p>Official logos and artwork should be available directly from the
+ repositories. These packages would be:</p>
<ul>
- <li><strong>archlinux-artwork</strong> - official logos, icons and CD labels</li>
- <li><strong>archlinux-wallpaper</strong> - a variety of desktop wallpapers
+ <li><strong>parabola-artwork</strong> - official logos, icons and CD labels</li>
+ <li><strong>parabola-wallpaper</strong> - a variety of desktop wallpapers
for standard and widescreen resolutions</li>
- <li><strong>archlinux-themes-kde</strong> - KDE themes and icons</li>
- <li><strong>archlinux-themes-kdm</strong> - KDM login themes</li>
- <li><strong>archlinux-themes-slim</strong> - SLiM login themes</li>
+ <li><strong>parabola-themes-kde</strong> - KDE themes and icons</li>
+ <li><strong>parabola-themes-kdm</strong> - KDM login themes</li>
+ <li><strong>parabola-themes-slim</strong> - SLiM login themes</li>
</ul>
-
- <p>Alternatively, you can <a href="ftp://ftp.archlinux.org/other/artwork/"
- title="Browse the FTP archives">download the source files via FTP</a>.</p>
-
- <h3>Former Logos</h3>
-
- <p>Arch has gone through a few generations of branding and what follows are
- some of our past logos. Although these images are no longer used frequently,
- they remain subject to license restrictions. Email
- <strong>trademarks@archlinux.org</strong> with any questions.</p>
-
- <h4>Original Ribbon Series</h4>
-
- <div class="imagelist">
- <img src="{% static "logos/legacy/arch-legacy-ribbon1.png" %}" alt="Arch Ribbon Logo 1"/>
- <img src="{% static "logos/legacy/arch-legacy-ribbon2.png" %}" alt="Arch Ribbon Logo 2"/>
- <img src="{% static "logos/legacy/arch-legacy-ribbon5.png" %}" alt="Arch Ribbon Logo 5"/>
- </div>
-
- <div class="imagelist">
- <img src="{% static "logos/legacy/arch-legacy-ribbon3.png" %}" alt="Arch Ribbon Logo 3"/>
- <img src="{% static "logos/legacy/arch-legacy-ribbon4.png" %}" alt="Arch Ribbon Logo 4"/>
- <img src="{% static "logos/legacy/arch-legacy-ribbon6.png" %}" alt="Arch Ribbon Logo 6"/>
- </div>
-
- <h4>"Arch Blue" Series</h4>
-
- <div class="imagelist">
- <a href="{% static "logos/legacy/arch-legacy-blue1.svg" %}" title="Arch Blue">
- <img src="{% static "logos/legacy/arch-legacy-blue1.png" %}" alt="Arch Blue"/></a>
- <a href="{% static "logos/legacy/arch-legacy-blue2.svg" %}" title="Arch Blue Vertical">
- <img src="{% static "logos/legacy/arch-legacy-blue2.png" %}" alt="Arch Blue Vertical"/></a>
- </div>
-
- <h4>"Arch Aqua" Series</h4>
-
- <div class="imagelist">
- <a href="{% static "logos/legacy/arch-legacy-aqua.svg" %}" title="Arch Aqua">
- <img src="{% static "logos/legacy/arch-legacy-aqua.png" %}" alt="Arch Aqua" /></a>
- <a href="{% static "logos/legacy/arch-legacy-aqua-blue.svg" %}" title="Arch Aqua Blue">
- <img src="{% static "logos/legacy/arch-legacy-aqua-blue.png" %}" alt="Arch Aqua Blue" /></a>
- <a href="{% static "logos/legacy/arch-legacy-aqua-white.svg" %}" title="Arch Aqua White">
- <img src="{% static "logos/legacy/arch-legacy-aqua-white.png" %}" alt="Arch Aqua White" /></a>
- </div>
-
- <h4>Release-specific Series</h4>
-
- <div class="imagelist">
- <a href="{% static "logos/legacy/arch-legacy-wombat-lg.png" %}" title="Arch Wombat">
- <img src="{% static "logos/legacy/arch-legacy-wombat.png" %}" alt="Arch Wombat" /></a>
- <a href="{% static "logos/legacy/arch-legacy-noodle-blue.svg" %}" title="Arch Noodle Blue">
- <img src="{% static "logos/legacy/arch-legacy-noodle-blue.png" %}" alt="Arch Noodle Blue" /></a>
- <a href="{% static "logos/legacy/arch-legacy-noodle-white.svg" %}" title="Arch Noodle White">
- <img src="{% static "logos/legacy/arch-legacy-noodle-white.png" %}" alt="Arch Noodle White" /></a>
- <a href="{% static "logos/legacy/arch-legacy-noodle-box.svg" %}" title="Arch Box of Noodles">
- <img src="{% static "logos/legacy/arch-legacy-noodle-box.png" %}" alt="Arch Box of Noodles" /></a>
- <a href="{% static "logos/legacy/arch-legacy-noodle-cup.svg" %}" title="Arch Cup of Noodles">
- <img src="{% static "logos/legacy/arch-legacy-noodle-cup.png" %}" alt="Arch Cup of Noodles" /></a>
- </div>
+{% endcomment %}
</div><!-- #artwork -->
{% endblock %}
diff --git a/templates/public/donate.html b/templates/public/donate.html
index 963a02ca..f7087dc9 100644
--- a/templates/public/donate.html
+++ b/templates/public/donate.html
@@ -1,6 +1,7 @@
{% extends "base.html" %}
{% load cache %}
{% load static from staticfiles %}
+{% load wiki %}
{% block title %}{{ BRANDING_DISTRONAME }} - Donate{% endblock %}
@@ -8,65 +9,20 @@
{% cache 600 donations secure %}
<div id="donations" class="box">
- <h2>Donate to Arch Linux</h2>
+ <h2>Donate to {{ BRANDING_SHORTNAME }}</h2>
- <p>Arch Linux survives because of the tireless efforts of many people in
- the community and the core development circle. None of us are paid for
- our work, and we don't have the personal funds to sustain server costs
- ourselves.</p>
+ <h3>We don't accept any money donations</h3>
- <p>There are many ways to help support Arch Linux. If technical development,
- documentation, or support aren't your strong points, you could certainly
- help us by dropping a few bucks our way.</p>
+ <p>That's right. At the moment, Parabola isn't accepting any money
+ donations. And that's because we have nothing to do with them. We really
+ don't, at the moment. So, some voluntary work is much preferred than
+ anything, because we are a really small community of hackers.</p>
- <p>Many thanks!</p>
+ <p>If you want, we have a pretty nice <a
+ href="{% wiki_url 'TODO' %}" title="The TODO
+ list!">TODO list</a> you can check to help us by donating some of your
+ time. That will be very much appreciated by us :)</p>
- <h3>Monetary donations</h3>
-
- <p>Financial contributions are accepted via <a href="https://co.clickandpledge.com/Default.aspx?WID=47294" title="Donate via Click&amp;Pledge to Arch Linux">Click&amp;Pledge</a>.
- Arch Linux is a member project of the
- <a href="http://www.spi-inc.org/">Software in the Public Interest, Inc.</a>
- non-profit corporation. Funds are used for hosting costs, server hardware
- upgrades, and more. You are encouraged to learn more about the SPI, as well
- as <a href="http://www.spi-inc.org/donations/">how donations work</a>.</p>
-
- <a href="https://co.clickandpledge.com/Default.aspx?WID=47294">
- <img width="210" height="34" src="{% static "click_and_pledge.png" %}" alt="Donate via Click&amp;Pledge to Arch Linux" title="Donate via Click&amp;Pledge to Arch Linux"/>
- </a>
-
- <h3>Commercial sponsors and contributions</h3>
-
- <p>We'd like to thank <a href="http://www.velocitynetwork.net/?hosting_by=ArchLinux"
- title="velocity network">Velocity Network</a> for contributing space
- in a server rack, bandwidth, and electricity for our main server.</p>
-
- <a href="http://www.velocitynetwork.net/?hosting_by=ArchLinux"
- title="velocity network"><img width="252" height="58" src="{% static "vnet_button.png" %}" class="sponsor-btn-vnet"
- title="" alt="velocity network - it's about time" /></a>
-
- <p>More thanks go to <a href="http://www.airvm.com/ArchLinux"
- title="AirVM.com">AirVM.com</a> for contributing a VMWare-based Virtual Machine.</p>
-
- <a href="http://www.airvm.com/ArchLinux"
- title="AirVM.com - Your Green Technology Partner"><img width="252" height="58" src="{% static "airvm_button.png" %}"
- class="sponsor-btn-airvm" title="AirVM.com - Your Green Technology Partner" alt="AirVM.com - Your Green Technology Partner" /></a>
-
- <p>We would also like to thank Kartenzia for sponsoring a dedicated Arch Linux Server.
- Kartenzia.de is a new Start-Up based in Germany and specializes in
- eco-friendly invitations like <a href="http://www.kartenzia.de/weihnachtskarten/">Weihnachten</a>.</p>
-
- <a href="http://www.kartenzia.de/"><img width="292" height="74" src="{% static "kartenzia_button.png" %}" class="sponsor-btn-kartenzia" /></a>
-
- <h3>Past donors</h3>
-
- <div id="donor-list">
- <ul>
-{% for donor in donors %}
-<li>{{ donor.name }}</li>{% endfor %}
- </ul>
- </div>
- <div class="clear"></div>
- <p>A huge thanks to you all for your contributions!</p>
</div>
{% endcache %}
{% endblock %}
diff --git a/templates/public/download.html b/templates/public/download.html
deleted file mode 100644
index 274d6cfd..00000000
--- a/templates/public/download.html
+++ /dev/null
@@ -1,114 +0,0 @@
-{% extends "base.html" %}
-{% load cache %}
-{% load static from staticfiles %}
-{% load flags %}
-{% load wiki %}
-
-{% block title %}{{ BRANDING_DISTRONAME }} - Downloads{% endblock %}
-
-{% block head %}
-<link rel="stylesheet" type="text/css" href="{% static "flags/fam.css" %}" media="screen, projection" />
-<link rel="alternate" type="application/rss+xml" title="{{BRANDING_DISTRONAME}} Releases" href="/feeds/releases/" />
-{% endblock %}
-
-{% block navbarclass %}anb-download{% endblock %}
-
-{% block content %}
-<div id="arch-downloads" class="box">
-
- <h2>{{BRANDING_DISTRONAME}} Downloads</h2>
-
- <h3>Release Info</h3>
-
- <p>The image can be burned to a CD, mounted as an ISO file,
- or be directly written to a USB stick using a utility like `dd`. It
- is intended for new installations only; an existing {{BRANDING_DISTRONAME}} system
- can always be updated with `pacman -Syu`.</p>
-
- <ul>
- {% if release.version %}<li><strong>Current Release:</strong> {{ release.version }}</li>{% endif %}
- {% if release.kernel_version %}<li><strong>Included Kernel:</strong> {{ release.kernel_version }}</li>{% endif %}
- {% if release.file_size %}<li><strong>ISO Size:</strong> {{ release.file_size|filesizeformat }}</li>{% endif %}
- <li><a href="{% wiki_url 'Installation_Guide' %}">Installation Guide</a></li>
- <li><strong>Resources:</strong>
- <ul>
- <li><a href="https://bugs.archlinux.org/index.php?project=6"
- title="Arch Linux Bugtracker:Release Engineering">Bug Tracker</a></li>
- <li><a href="{{ MAILMAN_BASE_URL }}/mailman/listinfo/arch-releng"
- title="Arch Linux Release Engineering mailing list">Mailing List</a></li>
- </ul>
- </li>
- </ul>
-
- {% if release.info %}
- <h3>Release Notes</h3>
-
- <div class="article-content">{{ release.info_html }}</div>
- {% endif %}
-
- <h3>Existing {{BRANDING_SHORTNAME}} Users</h3>
-
- <p>If you are an existing {{BRANDING_SHORTNAME}} user, there is no need to download a new ISO
- to update your existing system. You may be looking for
- <a href="{% url 'mirrorlist' %}">an updated mirrorlist</a> instead.</p>
-
- <h3>BitTorrent Download (recommended)</h3>
-
- <p>If you can spare the bytes, please leave the client open after your
- download is finished, so you can seed it back to others.
- <em>A web-seed capable client is recommended for fastest download speeds.</em></p>
-
- {% if release %}<ul>
- <li><a href="{{ release.magnet_uri }}"
- title="Magnet link">Magnet link for {{ release.version }}</a></li>
- <li><a href="{% url 'releng-release-torrent' release.version %}"
- title="Download torrent">Torrent for {{ release.version }}</a></li>
- </ul>{% endif %}
-
- <h3>Netboot</h3>
-
- <p>If you have a wired connection, you can boot the latest release directly over the network.</p>
- <ul>
- <li><a href="{{ releng_pxeboot_url }}"
- title="{{BRANDING_DISTRONAME}} Netboot Live System">{{BRANDING_DISTRONAME}} Linux Netboot</a></li>
- </ul>
-
- <h3>HTTP Direct Downloads</h3>
-
- <p>In addition to the BitTorrent links above, install images can also be
- downloaded via HTTP from the mirror sites listed below. Please
- ensure the download image matches the checksum from the md5sums.txt or
- sha1sums.txt file in the same directory as the image.</p>
-
- <h4>Checksums</h4>
-
- <p>File integrity checksums for the latest releases can be found below:</p>
-
- <ul>
- <li><a href="https://www.archlinux.org/{{ release.iso_url }}.sig"
- title="PGP signature">PGP signature</a></li>
- {% if release.md5_sum %}<li><strong>MD5:</strong> {{ release.md5_sum }}</li>{% endif %}
- {% if release.sha1_sum %}<li><strong>SHA1:</strong> {{ release.sha1_sum }}</li>{% endif %}
- </ul>
-
- {% cache 600 download-mirrors %}
- <div id="download-mirrors">
- {% regroup mirror_urls by country as grouped_urls %}
- {% for country in grouped_urls %}
- {% if country.grouper %}<h5>{% country_flag country.grouper %}{{ country.grouper.name }}</h5>
- {% else %}<h5>Worldwide</h5>{% endif %}
- <ul>
- {% for mirror_url in country.list %}
- <li><a href="{{ mirror_url.url }}{{ release.dir_path }}"
- title="Download from {{ mirror_url.url }}">{{ mirror_url.mirror.name }}</a></li>
- {% endfor %}
- </ul>
- {% endfor %}
- </div>
- {% endcache %}
-
- <p>If you want to become an Official {{BRANDING_DISTRONAME}} Mirror please follow the
- instructions listed <a href="{% wiki_url 'DeveloperWiki:NewMirrors' %}">here</a>.</p>
-
-</div>
-{% endblock %}
diff --git a/templates/public/feeds.html b/templates/public/feeds.html
index bb8e685a..70d8eee6 100644
--- a/templates/public/feeds.html
+++ b/templates/public/feeds.html
@@ -62,9 +62,6 @@
</tbody>
</table>
- <p>A <a href="https://aur.archlinux.org/rss.php" class="rss" title="AUR newest packages feed">newest packages feed</a>
- is also available from the <a href="https://aur.archlinux.org/" title="AUR Homepage">Arch User Repository (AUR)</a>.</p>
-
<h3>Release Feed</h3>
<p>Grab the <a href="/feeds/releases/" class="rss" title="{{BRANDING_DISTRONAME}} release feed">ISO release feed</a>
@@ -79,42 +76,57 @@
<thead>
<tr>
<th>Project</th>
- <th>Recently Opened Tasks</th>
- <th>Recently Edited Tasks</th>
- <th>Recently Closed Tasks</th>
+ <th>Activity</th>
+ <th>Issues</th>
+ <th>News</th>
</tr>
</thead>
<tbody>
<tr>
<td>All Projects</td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;project=0" class="rss">Feed</a></td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;topic=edit&amp;project=0" class="rss">Feed</a></td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;topic=clo&amp;project=0" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/activity.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/issues.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/news.atom" class="rss">Feed</a></td>
+ </tr><tr>
+ <td>Art4Parabola</td>
+ <td><a href="https://labs.parabola.nu/projects/art4parabola/activity.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/art4parabola/issues.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/art4parabola/news.atom" class="rss">Feed</a></td>
+ </tr><tr>
+ <td>Documentation</td>
+ <td><a href="https://labs.parabola.nu/projects/documentation/activity.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/documentation/issues.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/documentation/news.atom" class="rss">Feed</a></td>
+ </tr><tr>
+ <td>Installation media (i686 and x86_64)</td>
+ <td><a href="https://labs.parabola.nu/projects/isos/activity.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/isos/issues.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/isos/news.atom" class="rss">Feed</a></td>
</tr><tr>
- <td>Arch Linux</td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;project=1" class="rss">Feed</a></td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;topic=edit&amp;project=1" class="rss">Feed</a></td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;topic=clo&amp;project=1" class="rss">Feed</a></td>
+ <td>Libretools</td>
+ <td><a href="https://labs.parabola.nu/projects/libretools/activity.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/libretools/issues.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/libretools/news.atom" class="rss">Feed</a></td>
</tr><tr>
- <td>Release Engineering</td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;project=6" class="rss">Feed</a></td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;topic=edit&amp;project=6" class="rss">Feed</a></td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;topic=clo&amp;project=6" class="rss">Feed</a></td>
+ <td>Packages (i686 and x86_64)</td>
+ <td><a href="https://labs.parabola.nu/projects/issue-tracker/activity.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/issue-tracker/issues.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/issue-tracker/news.atom" class="rss">Feed</a></td>
</tr><tr>
- <td>Pacman Development</td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;project=3" class="rss">Feed</a></td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;topic=edit&amp;project=3" class="rss">Feed</a></td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;topic=clo&amp;project=3" class="rss">Feed</a></td>
+ <td>Ports</td>
+ <td><a href="https://labs.parabola.nu/projects/ports/activity.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/ports/issues.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/ports/news.atom" class="rss">Feed</a></td>
</tr><tr>
- <td>Community Packages</td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;project=5" class="rss">Feed</a></td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;topic=edit&amp;project=5" class="rss">Feed</a></td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;topic=clo&amp;project=5" class="rss">Feed</a></td>
+ <td>Port: Loongson 2F (mips64el)</td>
+ <td><a href="https://labs.parabola.nu/projects/mips64el/activity.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/mips64el/issues.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/mips64el/news.atom" class="rss">Feed</a></td>
</tr><tr>
- <td>AUR</td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;project=2" class="rss">Feed</a></td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;topic=edit&amp;project=2" class="rss">Feed</a></td>
- <td><a href="https://bugs.archlinux.org/feed.php?feed_type=rss2&amp;topic=clo&amp;project=2" class="rss">Feed</a></td>
+ <td>Servers</td>
+ <td><a href="https://labs.parabola.nu/projects/servers/activity.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/servers/issues.atom" class="rss">Feed</a></td>
+ <td><a href="https://labs.parabola.nu/projects/servers/news.atom" class="rss">Feed</a></td>
</tr>
</tbody>
</table>
diff --git a/templates/public/https.html b/templates/public/https.html
new file mode 100644
index 00000000..0d54c6c0
--- /dev/null
+++ b/templates/public/https.html
@@ -0,0 +1,38 @@
+{% extends "base.html" %}
+{% load wiki %}
+{% block title %}{{ BRANDING_DISTRONAME }} - HTTPS Only site{% endblock %}
+{% block content %}
+<div class="box">
+ <h2 class="title">{{ BRANDING_DISTRONAME }}</h2>
+
+ <p>Hi! This is not the main site. You're seeing this message because you
+ entered our website without using a secure connection. We like privacy for
+ all so we've decided to serve our website only through secure channels.</p>
+
+ <p>The website uses SSL certificates issued by <a
+ href="http://cacert.org">CACert</a>. Some web browsers or systems still
+ don't provide CACert's root certificate, so if you find a huge error
+ message telling you're about to do something bad, come back here and keep
+ reading.</p>
+
+ <p><a href="https://parabolagnulinux.org">Parabola GNU/Linux-libre</a></p>
+
+ <h3>I just want to get the ISOs</h3>
+
+ <p>You can proceed to our <a
+ href="{% wiki_url 'get' %}">ISOs download page</a> on <a
+ href="{% wiki_url %}">our wiki</a>.</p>
+
+ <h3>I want to do this the right way</h3>
+
+ <p>Ask your distribution to <a
+ href="http://wiki.cacert.org/InclusionStatus" title="CACert's inclusion
+ status">include</a> CACert's root certificates.</p>
+
+ <p>Alternatively, <a
+ href="http://www.cacert.org/index.php?id=3">install</a> the root
+ certificate in your browser. <a
+ href="http://wiki.cacert.org/BrowserClients">(more details here.)</a></p>
+
+</div>
+{% endblock %}
diff --git a/templates/public/index.html b/templates/public/index.html
index b32260b5..40d887b7 100644
--- a/templates/public/index.html
+++ b/templates/public/index.html
@@ -11,26 +11,25 @@
{% block content_left %}
{% cache 62 main-page-left secure %}
<div id="intro" class="box">
- <h2>A simple, lightweight distribution</h2>
+ <h2>A <em>libre</em> version of Arch Linux</h2>
- <p>You've reached the website for <strong>Arch Linux</strong>, a
- lightweight and flexible Linux® distribution that tries to Keep It
- Simple.</p>
+ <p>You've reached the website for <strong>{{BRANDING_DISTRONAME}}</strong>,
+ a project aiming to provide a fully free (as in freedom)
+ derivative of Arch Linux, the lightweight and flexible GNU/Linux
+ distribution that tries to Keep It Simple.</p>
- <p>Currently we have official packages optimized for the i686 and
- x86-64 architectures. We complement our official package sets with a
- <a href="https://aur.archlinux.org/" title="Arch User Repository (AUR)">
- community-operated package repository</a> that grows in size and
- quality each and every day.</p>
+ <p>Currently we provide the official packages from Arch that meet
+ the <a href="http://www.gnu.org/distros/free-system-distribution-guidelines.html">FSDG</a>,
+ replacements for those that don't, and our own additions, all of
+ them optimized for the i686, x86-64, and mips64el architectures.</p>
- <p>Our strong community is diverse and helpful, and we pride ourselves
- on the range of skillsets and uses for Arch that stem from it. Please
- check out our <a href="https://bbs.archlinux.org/" title="Arch Forums">forums</a>
+ <p>Our strong community is diverse and helpful. Please
+ check out our <a href="irc://chat.freenode.net#parabola" title="IRC channel">IRC channel</a>
and <a href="{{ MAILMAN_BASE_URL }}/mailman/listinfo/"
- title="Arch Mailing Lists">mailing lists</a>
+ title="{{ BRANDING_SHORTNAME }} Mailing Lists">mailing lists</a>
to get your feet wet. Also glance through our <a href="{% wiki_url %}"
title="{{BRANDING_WIKINAME}}">wiki</a>
- if you want to learn more about Arch.</p>
+ if you want to learn more about {{BRANDING_SHORTNAME}}.</p>
<p class="readmore"><a href="{% url 'page-about' %}"
title="Learn more about {{ BRANDING_DISTRONAME }}">Learn more...</a></p>
@@ -115,8 +114,10 @@
title="Community documentation">Wiki</a></li>
<li><a href="{% wiki_url 'Installation Guide' %}"
title="Official installation guide">Official Installation Guide</a></li>
- <li><a href="%{ wiki_url "Beginners'_Guide" %}"
+ <li><a href="{% wiki_url "Beginners'_Guide" %}"
title="A good place to start for beginners">Unofficial Beginners' Guide</a></li>
+ <li><a href="{% wiki_url 'Migration' %}"
+ title="Free your Arch installation">Migration from Arch Linux</a></li>
</ul>
<h4>Community</h4>
@@ -126,10 +127,8 @@
title="Community and developer mailing lists">Mailing Lists</a></li>
<li><a href="{% wiki_url 'IRC_Channels' %}"
title="Official and regional IRC communities">IRC Channels</a></li>
- <li><a href="https://planet.archlinux.org/"
- title="Arch in the blogosphere">Planet Arch</a></li>
- <li><a href="{% wiki_url 'International_Communities' %}"
- title="{{DISTRO_SHORTNAME}} communities in your native language">International Communities</a></li>
+ <li><a href="https://identi.ca/group/parabola"
+ title="Parabola at identi.ca">Identi.ca group</a></li>
</ul>
<h4>Support</h4>
@@ -137,12 +136,6 @@
<ul>
<li><a href="{% url 'page-donate' %}"
title="Help support {{ BRANDING_DISTRONAME }}">Donate</a></li>
- <li><a href="http://schwag.archlinux.ca/"
- title="USB keys, jewellery, case badges">Arch Schwag</a></li>
- <li><a href="http://www.zazzle.com/archlinux*"
- title="T-shirts, mugs, mouse pads, hoodies, posters, skateboards, shoes, etc.">Products via Zazzle</a></li>
- <li><a href="http://www.freewear.org/?page=list_items&amp;org=Archlinux"
- title="T-shirts">T-shirts via Freewear</a></li>
</ul>
<h4>Tools</h4>
@@ -161,16 +154,18 @@
<h4>Development</h4>
<ul>
- <li><a href="https://projects.archlinux.org/"
- title="Official Arch projects (git)">Projects in Git</a></li>
+ <li><a href="https://projects.parabolagnulinux.org"
+ title="Official Parabola projects (git)">Projects in Git</a></li>
+{% comment %}
<li><a href="{% url 'page-svn' %}"
title="View SVN entries for packages">SVN Repositories</a></li>
<li><a href="{% wiki_url 'DeveloperWiki' %}"
title="Developer Wiki articles">Developer Wiki</a></li>
+{% endcomment %}
<li><a href="/groups/"
title="View the available package groups">Package Groups</a></li>
<li><a href="/todo/"
- title="Developer Todo Lists">Todo Lists</a></li>
+ title="Hacker Todo Lists">Todo Lists</a></li>
<li><a href="{% url 'visualize-index' %}"
title="View visualizations">Visualizations</a></li>
</ul>
@@ -180,30 +175,44 @@
<ul>
<li><a href="{% url 'page-keys' %}"
title="Package/Database signing master keys">Signing Master Keys</a></li>
- <li><a href="{% wiki_url 'Arch_Linux_Press_Review' %}"
- title="Arch Linux in the media">Press Coverage</a></li>
+ <li><a href="{% wiki_url 'Media' %}"
+ title="{{ BRANDING_DISTRONAME }} in the media">Press Coverage</a></li>
<li><a href="{% url 'page-art' %}" title="{{ BRANDING_SHORTNAME }} logos and other artwork for promotional use">Logos &amp; Artwork</a></li>
<li><a href="{% url 'news-list' %}" title="News Archives">News Archives</a></li>
<li><a href="/feeds/" title="Various RSS Feeds">RSS Feeds</a></li>
- <li><a href="{% url 'page-devs' %}" title="Active developers">Developer Profiles</a></li>
- <li><a href="{% url 'page-tus' %}" title="Active Trusted Users (TUs)">Trusted User Profiles</a></li>
- <li><a href="{% url 'page-fellows' %}" title="Retired Developers">Fellows Profiles</a></li>
+ <li><a href="{% url 'page-devs' %}" title="Active hackers">Hackers Profiles</a></li>
+ <li><a href="{% url 'page-fellows' %}" title="Retired hackers">Fellows Profiles</a></li>
</ul>
</div>
+{% comment %}
<div id="home-donate-button" class="widget">
- <a href="https://co.clickandpledge.com/Default.aspx?WID=47294">
- <img width="210" height="34" src="{% static "click_and_pledge.png" %}" alt="Donate via Click&amp;Pledge to Arch Linux" title="Donate via Click&amp;Pledge to Arch Linux"/>
- </a>
+donate button would go here
</div>
+{% endcomment %}
<div id="arch-sponsors" class="widget">
- <a href="http://www.velocitynetwork.net/?hosting_by=ArchLinux" title="Velocity Network">
- <img width="252" height="58" src="{% static "vnet_button.png" %}" alt="Velocity Network - It's about time" />
+ <a href="http://gnuchile.cl">
+ <img src="{% static "gnuchile.png" %}"
+ alt="GNU Chile - Donates the .org domain"
+ title="GNU Chile - Donates the .org domain" />
</a>
- <a href="http://www.airvm.com/ArchLinux" title="AirVM.com - Your Green Technology Partner">
- <img width="252" height="58" src="{% static "airvm_button.png" %}" alt="AirVM.com - Your Green Technology Partner" />
+
+ <img src="{% static "venenux.png" %}"
+ alt="Venenux GNU/Linux - Donates the repo, wiki and lists hosting"
+ title="Venenux GNU/Linux - Donates the repo, wiki and lists hosting" />
+
+ <a href="http://naltu.com">
+ <img src="{% static "naltu.png" %}"
+ alt="Naltú - Donates the website, bugs, projects and ABSLibre hosting"
+ title="Naltú - Donates the website, bugs, projects and ABSLibre hosting" />
+ </a>
+
+ <a href="http://freedomincluded.com">
+ <img src="{% static "freedomincluded.png" %}"
+ alt="Freedom Included - Donated Lemote Yeeloongs to port Parabola to the MIPS architecture"
+ title="Freedom Included - Donated Lemote Yeeloongs to port Parabola to the MIPS architecture" />
</a>
</div>
{% endcache %}
diff --git a/templates/public/svn.html b/templates/public/svn.html
deleted file mode 100644
index 88c6df93..00000000
--- a/templates/public/svn.html
+++ /dev/null
@@ -1,41 +0,0 @@
-{% extends "base.html" %}
-{% block title %}{{ BRANDING_DISTRONAME }} - SVN{% endblock %}
-{% block content %}
-<div class="box">
- <h2 class="title">SVN Repositories</h2>
- <p>
- The PKGBUILD files can be fetched via the ABS utility. To learn more
- about ABS, see <a href="{% wiki_url 'ABS' %}">the ABS wiki page</a>.
- </p>
- <p>The SVN repositories have been cloned into git repositories and can be
- viewed via the cgit interface.
- <a href="https://projects.archlinux.org/svntogit/packages.git/">All
- packages</a> are available here except for
- <a href="https://projects.archlinux.org/svntogit/community.git/">community
- and multilib</a> which are available in a different repository.</p>
- <p>
- You can also get individual PKGBUILDs directly from SVN. This can be
- especially useful if you need to compile an older version of a package.
- <strong>DO NOT CHECK OUT THE ENTIRE SVN REPO</strong>. Your address may be
- blocked. Use the following commands to check out a specific package:
- </p>
-
- <pre>svn checkout --depth=empty svn://svn.archlinux.org/packages
-cd packages
-svn update &lt;your-package-name&gt;</pre>
-
- For the community and multilib repositories, use the following commands
- instead:
- <pre>svn checkout --depth=empty svn://svn.archlinux.org/community
-cd community
-svn update &lt;your-package-name&gt;</pre>
-
- <p>
- Visit <a href="{% wiki_url 'Getting_PKGBUILDS_From_SVN' %}">the wiki</a>
- for more tips on checking out and updating svn PKGBUILDs.
- </p>
-
-</div>
-<br /><br />
-{% endblock %}
-
diff --git a/urls.py b/urls.py
index 79838ce3..2014f0aa 100644
--- a/urls.py
+++ b/urls.py
@@ -26,12 +26,11 @@ urlpatterns += patterns('public.views',
(r'^$', 'index', {}, 'index'),
(r'^about/$', TemplateView.as_view(template_name='public/about.html'),
{}, 'page-about'),
+ (r'^https/$', TemplateView.as_view(template_name='public/https.html'),
+ {}, 'page-https'),
(r'^art/$', TemplateView.as_view(template_name='public/art.html'),
{}, 'page-art'),
- (r'^svn/$', TemplateView.as_view(template_name='public/svn.html'),
- {}, 'page-svn'),
- (r'^developers/$', 'userlist', { 'user_type':'devs' }, 'page-devs'),
- (r'^trustedusers/$', 'userlist', { 'user_type':'tus' }, 'page-tus'),
+ (r'^hackers/$', 'userlist', { 'user_type':'hackers' }, 'page-devs'),
(r'^fellows/$', 'userlist', { 'user_type':'fellows' }, 'page-fellows'),
(r'^donate/$', 'donate', {}, 'page-donate'),
(r'^download/$', 'download', {}, 'page-download'),
@@ -73,11 +72,6 @@ urlpatterns += patterns('',
{}, 'opensearch-packages-suggest'),
)
-# Retro home page views
-urlpatterns += patterns('retro.views',
- (r'^retro/(?P<year>[0-9]{4})/$', 'retro_homepage', {}, 'retro-homepage'),
-)
-
# Sitemaps
urlpatterns += patterns('',
(r'^sitemap.xml$',
@@ -111,11 +105,14 @@ legacy_urls = (
('^todolists/$', '/todo/'),
('^docs/en/guide/install/arch-install-guide.html',
- 'https://wiki.archlinux.org/index.php/Installation_Guide'),
+ 'https://wiki.parabolagnulinux.org/Installation_Guide'),
('^docs/en/',
- 'https://wiki.archlinux.org/'),
+ 'https://wiki.parabolagnulinux.org/'),
('^docs/',
- 'https://wiki.archlinux.org/'),
+ 'https://wiki.parabolagnulinux.org/'),
+
+ ('^developers/$', '/hackers/'),
+ ('^trustedusers/$', '/hackers/'),
)
urlpatterns += [url(old_url, RedirectView.as_view(url=new_url))
diff --git a/visualize/static/.gitignore b/visualize/static/.gitignore
new file mode 100644
index 00000000..ecb2b9c4
--- /dev/null
+++ b/visualize/static/.gitignore
@@ -0,0 +1,3 @@
+.d3
+d3.v2.js
+d3.v2.min.js
diff --git a/visualize/static/Makefile b/visualize/static/Makefile
new file mode 100644
index 00000000..4fa99a20
--- /dev/null
+++ b/visualize/static/Makefile
@@ -0,0 +1,41 @@
+d3version=2.8.1
+
+targets=d3.v2.js d3.v2.min.js
+gitignore=.d3
+
+# Force creating the d3 directory before we even evaluate how to make d3.js
+all: .d3/d3-$(d3version) .gitignore
+ $(MAKE) $(targets)
+
+distclean-hook: PHONY
+ rm -rf .d3
+
+####
+
+d3.%: .d3/d3-$(d3version)/d3.% .d3/d3-$(d3version)/LICENSE Makefile
+ @echo '[D3-HEADER] > $@'
+ @echo '/* $@ - Data Driven Documents' > $@
+ @echo ' * Version: $(d3version)' >> $@
+ @echo ' * Homepage: http://mbostock.github.com/d3/' >> $@
+ @echo ' * Copyright: 2010, Michael Bostock' >> $@
+ @echo ' * Licence: 3-Clause BSD' >> $@
+ @echo ' *' >> $@
+ @sed 's/.*/ * &/' $(<D)/LICENSE >> $@
+ @echo ' */' >> $@
+ cat $< >> $@
+
+.d3/d3-%.tar.gz: Makefile
+ mkdir -p $(@D)
+ wget https://github.com/mbostock/d3/tarball/v$* -O $@
+.d3/d3-%.tar.gz.d: .d3/d3-%.tar.gz Makefile
+ rm -rf $@
+ mkdir -p $<.d
+ cd $@ && tar xzf ../d3-$*.tar.gz
+.d3/d3-%: .d3/d3-%.tar.gz.d Makefile
+ rm -rf $@
+ cp -r $</*/ $@
+ rm $@/*.min.js
+
+####
+
+include ../../sitestatic/js.mk
diff --git a/visualize/static/visualize.js b/visualize/static/visualize.js
index 5004fe6c..ff39bb96 100644
--- a/visualize/static/visualize.js
+++ b/visualize/static/visualize.js
@@ -1,3 +1,23 @@
+/* archweb.js
+ * Homepage: https://projects.archlinux.org/archweb.git/
+ * Copyright: 2011 Dan McGee
+ * License: GPLv2
+ *
+ * This file is part of Archweb.
+ *
+ * Archweb is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ *
+ * Archweb is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with Archweb. If not, see <http://www.gnu.org/licenses/>.
+ */
+
function packages_treemap(chart_id, orderings, default_order) {
var jq_div = jQuery(chart_id),
color = d3.scale.category20();
diff --git a/settings.py b/settings.py
index 1cb85fc1..25b2e09e 100644
--- a/settings.py
+++ b/settings.py
@@ -1,5 +1,5 @@
import os
# Django settings for archweb project.
## Set the debug values
DEBUG = False
@@ -13,7 +13,7 @@ ADMINS = ()
MANAGERS = ADMINS
# Package out-of-date emails for orphans
-NOTIFICATIONS = ['arch-notifications@archlinux.org']
+NOTIFICATIONS = ['dev@lists.parabolagnulinux.org']
# Full path to the data directory
DEPLOY_PATH = os.path.dirname(os.path.realpath(__file__))
@@ -156,20 +156,23 @@ LOGGING = {
PGP_SERVER = 'pgp.mit.edu:11371'
# URL to fetch a current list of available ISOs
-ISO_LIST_URL = 'https://releng.archlinux.org/isos/'
+ISO_LIST_URL = 'https://repo.parabolagnulinux.org/isos/'
# URL to the PXE netboot instructions
-PXEBOOT_URL = 'https://releng.archlinux.org/pxeboot/'
+PXEBOOT_URL = 'http://repo.parabolagnulinux.org/pxeboot/'
# URL for SVN access for fetching commit messages (note absence of packages or
# community bit on the end, repo.svn_root is appended)
-SVN_BASE_URL = 'svn://svn.archlinux.org/'
+#SVN_BASE_URL = 'svn://svn.archlinux.org/'
# URL for linking to mailing lists
-MAILMAN_BASE_URL = 'https://mailman.archlinux.org/'
+MAILMAN_BASE_URL = 'https://lists.parabolagnulinux.org/'
# URL for linking to the bugtracker
-BUGTRACKER_URL = 'https://bugs.archlinux.org/'
+BUGTRACKER_URL = 'https://labs.parabola.nu/'
+
+# URL for linking to the release engineering/iso project on the bugtracker
+BUGTRACKER_RELENG_URL = 'https://labs.parabola.nu/projects/isos'
# Trackers used for ISO download magnet links
TORRENT_TRACKERS = (
@@ -177,13 +180,14 @@ TORRENT_TRACKERS = (
'http://tracker.archlinux.org:6969/announce',
)
-DOMAIN_RE = r'^(.+\.)?archlinux.org$'
+DOMAIN_RE = r'^(.+\.)?parabolagnulinux.org$'
-BRANDING_APPNAME = 'archweb'
-BRANDING_DISTRONAME = 'Arch Linux'
-BRANDING_SHORTNAME = 'Arch'
-BRANDING_WIKINAME = 'ArchWiki'
-BRANDING_EMAIL = 'Arch Website Notification <nobody@archlinux.org>'
+BRANDING_APPNAME = 'parabolaweb'
+BRANDING_DISTRONAME = 'Parabola GNU/Linux-libre'
+BRANDING_SHORTNAME = 'Parabola'
+BRANDING_WIKINAME = 'ParabolaWiki'
+BRANDING_EMAIL = 'Parabola Website Notification <nobody@parabolagnulinux.org>'
+BRANDING_OSEARCH_TAGS = 'gnu linuxlibre parabola package software'
## Import local settings
from local_settings import *
@@ -1,5 +1,5 @@
import os
-# Django settings for archweb project.
+# Django settings for parabolaweb project.
## Set the debug values
DEBUG = False